@@ -6,20 +6,20 @@
     :date: 2021/09/02 22:20:52
 '''
 
+from school_sdk.client.api.score import Score
+from school_sdk.config import URL_ENDPOINT
 from school_sdk.client.api.schedules import Schedule
-from school_sdk.client.api import login
 from school_sdk.client.exceptions import LoginException
 import time
 from school_sdk.client.api.login import ZFLogin
 from school_sdk.client.base import BaseSchoolClient
-from school_sdk.utils import ObjectDict
 
 
 class SchoolClient():
 
     def __init__(self, host, port:int=80, ssl:bool=False, name=None, exist_verify:bool=False,
                 lan_host=None, lan_port=80, timeout=10,
-                login_url_path=None, url_path_list=None) -> None:
+                login_url_path=None, url_endpoints=None) -> None:
         """初始化学校配置
 
         Args:
@@ -32,7 +32,7 @@ class SchoolClient():
             lan_port (int, optional): 内网主机端口号. Defaults to 80.
             timeout (int, optional): 请求超时时间. Defaults to 10.
             login_url_path ([type], optional): 登录地址. Defaults to None.
-            url_path_list ([type], optional): 地址列表. Defaults to None.
+            url_endpoints ([dict], optional): 地址列表. Defaults to None.
         """
         school = {
             "name": name,
@@ -41,7 +41,7 @@ class SchoolClient():
             "lan_port": lan_port,
             "timeout": timeout,
             "login_url_path": login_url_path,
-            "url_path_list": url_path_list
+            "url_endpoints": url_endpoints or URL_ENDPOINT
         }
 
         self.base_url = f'https://{host}:{port}' if ssl else f'http://{host}:{port}'
@@ -60,7 +60,7 @@ class SchoolClient():
 
 class UserClient(BaseSchoolClient):
     schedule:Schedule = None
-
+    score: Score = None
     def __init__(self, school, account, password) -> None:
         """初始化用户类
         用户类继承自学校
@@ -80,7 +80,7 @@ class UserClient(BaseSchoolClient):
     def login(self):
         """用户登录，通过SchoolClient调用
         """
-        user = ZFLogin(school=self.school, account=self.account, password=self.password)
+        user = ZFLogin(user_client=self)
         user.get_raw_csrf_and_cookie()
         user.get_rsa_publick_key()
         try:
@@ -94,7 +94,12 @@ class UserClient(BaseSchoolClient):
         if self.schedule is None:
             self.schedule = Schedule(self)
 
-    def get_schedule(self):
+    def get_schedule(self, **kwargs):
         if self.schedule is None:
             self.schedule = Schedule(self)
-        return self.schedule.get_schedule_dict()
\ No newline at end of file
+        return self.schedule.get_schedule_dict(**kwargs)
+    
+    def get_score(self, **kwargs):
+        if self.score is None:
+            self.score = Score(self)
+        return self.score.get_score(**kwargs)
\ No newline at end of file
